@@ -103,12 +103,8 @@ void LauncherTasksModel::Private::init()
                                            AbstractTasksModel::LauncherUrlWithoutIcon});
     });
 
-    void (KSycoca::*myDatabaseChangeSignal)(const QStringList &) = &KSycoca::databaseChanged;
-    QObject::connect(KSycoca::self(), myDatabaseChangeSignal, q, [this](const QStringList &changedResources) {
-        if (changedResources.contains(QLatin1String("services")) || changedResources.contains(QLatin1String("apps"))
-            || changedResources.contains(QLatin1String("xdgdata-apps"))) {
-            sycocaChangeTimer.start();
-        }
+    QObject::connect(KSycoca::self(), &KSycoca::databaseChanged, q, [this]() {
+        sycocaChangeTimer.start();
     });
 }
 
@@ -187,9 +183,9 @@ bool LauncherTasksModel::Private::requestAddLauncherToActivities(const QUrl &_ur
             if (newActivities != activitiesForLauncher[launcher]) {
                 setActivitiesForLauncher(launcher, newActivities);
 
-                emit q->dataChanged(q->index(row, 0), q->index(row, 0));
+                Q_EMIT q->dataChanged(q->index(row, 0), q->index(row, 0));
 
-                emit q->launcherListChanged();
+                Q_EMIT q->launcherListChanged();
                 return true;
             }
 
@@ -204,7 +200,7 @@ bool LauncherTasksModel::Private::requestAddLauncherToActivities(const QUrl &_ur
     launchersOrder.append(url);
     q->endInsertRows();
 
-    emit q->launcherListChanged();
+    Q_EMIT q->launcherListChanged();
 
     return true;
 }
@@ -269,11 +265,11 @@ bool LauncherTasksModel::Private::requestRemoveLauncherFromActivities(const QUrl
             } else if (update) {
                 setActivitiesForLauncher(url, newActivities);
 
-                emit q->dataChanged(q->index(row, 0), q->index(row, 0));
+                Q_EMIT q->dataChanged(q->index(row, 0), q->index(row, 0));
             }
 
             if (remove || update) {
-                emit q->launcherListChanged();
+                Q_EMIT q->launcherListChanged();
                 return true;
             }
         }
@@ -333,6 +329,8 @@ QVariant LauncherTasksModel::data(const QModelIndex &index, int role) const
         return true;
     } else if (role == Activities) {
         return QStringList(d->activitiesForLauncher[url].values());
+    } else if (role == CanLaunchNewInstance) {
+        return false;
     }
 
     return QVariant();
@@ -450,7 +448,7 @@ void LauncherTasksModel::setLauncherList(const QStringList &serializedLaunchers)
 
         endResetModel();
 
-        emit launcherListChanged();
+        Q_EMIT launcherListChanged();
     }
 }
 
